@@ -18,18 +18,21 @@
 #' \dontrun{
 #' table(fct_match(gss_cat$marital, c("Maried", "Davorced")))
 #' }
-#'
 fct_match <- function(f, lvls) {
   f <- check_factor(f)
+  if (identical(lvls, NA)) {
+    lvls <- NA_character_
+  }
+  check_character(lvls)
 
   bad_lvls <- setdiff(lvls, levels(f))
   bad_lvls <- bad_lvls[!is.na(bad_lvls)]
   if (length(bad_lvls) > 0) {
-    stop(
-      "Levels not present in factor: ",
-      paste0(encodeString(bad_lvls, quote = '"'), collapse = ", "),
-      call. = FALSE
-    )
+    missing <- encodeString(bad_lvls, quote = '"')
+    cli::cli_abort(c(
+      "All {.arg lvls} must be present in {.arg f}.",
+      i = "Missing levels: {missing}"
+    ))
   }
 
   f %in% lvls
